@@ -3,7 +3,7 @@ package Starlight::Server;
 use strict;
 use warnings;
 
-our $VERSION = '0.0306';
+our $VERSION = '0.0400';
 
 use Config;
 
@@ -55,6 +55,8 @@ sub new {
         ipv6                 => $args{ipv6},
         ssl_key_file         => $args{ssl_key_file},
         ssl_cert_file        => $args{ssl_cert_file},
+        ssl_ca_file          => $args{ssl_ca_file},
+        ssl_verify_mode      => $args{ssl_verify_mode},
         user                 => $args{user},
         group                => $args{group},
         umask                => $args{umask},
@@ -126,8 +128,11 @@ sub prepare_socket_class {
     } elsif ($self->{ssl}) {
         try { require IO::Socket::SSL; 1 }
             or die "SSL suport requires IO::Socket::SSL\n";
-        $args->{SSL_key_file}  = $self->{ssl_key_file};
-        $args->{SSL_cert_file} = $self->{ssl_cert_file};
+        $args->{SSL_key_file}       = $self->{ssl_key_file};
+        $args->{SSL_cert_file}      = $self->{ssl_cert_file};
+        $args->{SSL_ca_file}        = $self->{ssl_ca_file};
+        $args->{SSL_client_ca_file} = $self->{ssl_ca_file};
+        $args->{SSL_verify_mode}    = $self->{ssl_verify_mode};
         return "IO::Socket::SSL";
     } elsif ($self->{ipv6}) {
         try { require IO::Socket::IP; 1 }
