@@ -23,7 +23,7 @@ package.
 
 Starlight was started as a fork of L<Thrall> server which is a fork of
 L<Starlet> server. It has almost the same code as L<Thrall> and L<Starlet> and
-it was adapted to doesn't use any other modules than L<Plack>.
+it was adapted to not use any other modules than L<Plack>.
 
 Starlight is created for Unix-like systems but it should also work on Windows
 with some limitations.
@@ -38,7 +38,7 @@ use 5.008_001;
 use strict;
 use warnings;
 
-our $VERSION = '0.0306';
+our $VERSION = '0.0400';
 
 use Plack::Runner;
 
@@ -113,6 +113,16 @@ Specifies the path to SSL key file. (default: none)
 
 Specifies the path to SSL certificate file. (default: none)
 
+=head2 --ssl-ca-file
+
+Specifies the path to SSL CA certificate file used when verification mode is
+enabled. (default: none)
+
+=head2 --ssl-verify-mode
+
+Sets the verification mode for the peer certificate. See
+L<IO::Socket::SSL/SSL_verify_mode>. (default: 0)
+
 =head2 --ipv6
 
 Enables IPv6 support. The L<IO::Socket::IP> module is required. (default: 0)
@@ -256,7 +266,7 @@ Paul Seamons <paul@seamons.com>
 
 =head1 LICENSE
 
-Copyright (c) 2013-2016 Piotr Roszatycki <dexter@cpan.org>.
+Copyright (c) 2013-2016, 2020 Piotr Roszatycki <dexter@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as perl itself.
